summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorGregory Nutt <gnutt@nuttx.org>2013-04-23 17:41:30 -0600
committerGregory Nutt <gnutt@nuttx.org>2013-04-23 17:41:30 -0600
commitaedf34777d0ff3783dcde562d768c2d31331d82b (patch)
tree5f90ff68c88b5c4fdd7a4e76e1fe52083f510fcc
parent385413eff99d22658833085adfe30e7e451f57cd (diff)
downloadpx4-nuttx-aedf34777d0ff3783dcde562d768c2d31331d82b.tar.gz
px4-nuttx-aedf34777d0ff3783dcde562d768c2d31331d82b.tar.bz2
px4-nuttx-aedf34777d0ff3783dcde562d768c2d31331d82b.zip
Some cosmetic renaming
-rw-r--r--nuttx/configs/pic32-starterkit/README.txt2
-rw-r--r--nuttx/sched/task_exithook.c16
2 files changed, 10 insertions, 8 deletions
diff --git a/nuttx/configs/pic32-starterkit/README.txt b/nuttx/configs/pic32-starterkit/README.txt
index 6a1f6b4c1..485a88b89 100644
--- a/nuttx/configs/pic32-starterkit/README.txt
+++ b/nuttx/configs/pic32-starterkit/README.txt
@@ -1206,7 +1206,7 @@ Where <subdir> is one of the following:
-CONFIG_EXAMPLES_USBMSC_DEVPATH1="/dev/mmcsd0"
+CONFIG_EXAMPLES_USBMSC_DEVPATH1="/dev/ram0"
- 2. Changes to nuttx/.config.
+ 2. Changes to apps/.config.
a) Enable building of the examples/usbstorage:
diff --git a/nuttx/sched/task_exithook.c b/nuttx/sched/task_exithook.c
index b59f8e5ba..7e1fbdf0c 100644
--- a/nuttx/sched/task_exithook.c
+++ b/nuttx/sched/task_exithook.c
@@ -417,15 +417,15 @@ static inline void task_sigchild(FAR struct tcb_s *ptcb,
#endif /* CONFIG_SCHED_HAVE_PARENT */
/****************************************************************************
- * Name: task_leavegroup
+ * Name: task_signalparent
*
* Description:
- * Send the SIGCHILD signal to the parent thread
+ * Send the SIGCHILD signal to the parent task group
*
****************************************************************************/
#ifdef CONFIG_SCHED_HAVE_PARENT
-static inline void task_leavegroup(FAR struct tcb_s *ctcb, int status)
+static inline void task_signalparent(FAR struct tcb_s *ctcb, int status)
{
#ifdef HAVE_GROUP_MEMBERS
DEBUGASSERT(ctcb && ctcb->group);
@@ -446,7 +446,7 @@ static inline void task_leavegroup(FAR struct tcb_s *ctcb, int status)
sched_lock();
/* Get the TCB of the receiving, parent task. We do this early to
* handle multiple calls to task_leavegroup. ctcb->ppid is set to an
* invalid value below and the following call will fail if we are
* called again.
*/
@@ -471,7 +471,7 @@ static inline void task_leavegroup(FAR struct tcb_s *ctcb, int status)
#endif
}
#else
-# define task_leavegroup(ctcb,status)
+# define task_signalparent(ctcb,status)
#endif
/****************************************************************************
@@ -626,6 +626,7 @@ void task_exithook(FAR struct tcb_s *tcb, int status, bool nonblocking)
* the exit functions *not* be called.
*/
+#if defined(CONFIG_SCHED_ATEXIT) || defined(CONFIG_SCHED_ONEXIT)
if (!nonblocking)
{
task_atexit(tcb);
@@ -634,6 +635,7 @@ void task_exithook(FAR struct tcb_s *tcb, int status, bool nonblocking)
task_onexit(tcb, status);
}
+#endif
/* If the task was terminated by another task, it may be in an unknown
* state. Make some feeble effort to recover the state.
@@ -641,9 +643,9 @@ void task_exithook(FAR struct tcb_s *tcb, int status, bool nonblocking)
task_recover(tcb);
- /* Leave the task group */
+ /* Send the SIGCHILD signal to the parent task group */
- task_leavegroup(tcb, status);
+ task_signalparent(tcb, status);
/* Wakeup any tasks waiting for this task to exit */
@@ -446,7 +446,7 @@ static inline void task_leavegroup(FAR struct tcb_s *ctcb, int status)
sched_lock();
/* Get the TCB of the receiving, parent task. We do this early to
- * handle multiple calls to task_leavegroup. ctcb->ppid is set to an
+ * handle multiple calls to task_signalparent. ctcb->ppid is set to an
* invalid value below and the following call will fail if we are
* called again.